summaryrefslogtreecommitdiffstats
path: root/kdat/InfoShellWidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdat/InfoShellWidget.h')
-rw-r--r--kdat/InfoShellWidget.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kdat/InfoShellWidget.h b/kdat/InfoShellWidget.h
index f7046db..ae8dd90 100644
--- a/kdat/InfoShellWidget.h
+++ b/kdat/InfoShellWidget.h
@@ -22,18 +22,19 @@
#include <tqwidget.h>
/**
* @short A suitable parent for the info widgets.
*/
class InfoShellWidget : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Create a new info shell widget.
*
* @param parent The parent widget.
* @param name The name of this widget.
*/
- InfoShellWidget( TQWidget* parent = 0, const char* name = 0 );
+ InfoShellWidget( TQWidget* tqparent = 0, const char* name = 0 );
/**
* Destroy the info shell widget.
@@ -41,7 +42,7 @@ public:
~InfoShellWidget();
protected:
/**
- * Resize all children to fill all of the available space within the shell.
+ * Resize all tqchildren to fill all of the available space within the shell.
*/
virtual void resizeEvent( TQResizeEvent* e );
};
@@ -22,18 +22,19 @@
#include <tqwidget.h>
/**
- * @short A suitable parent for the info widgets.
+ * @short A suitable tqparent for the info widgets.
*/
class InfoShellWidget : public TQWidget {
@@ -22,18 +22,19 @@
* Create a new info shell widget.
*
- * @param parent The parent widget.
+ * @param tqparent The tqparent widget.
* @param name The name of this widget.
*/